#!/usr/bin/env bash
set -e
set -u
set -o pipefail

check_well_known () {
  # check if .well-know is created
  scheme="https"
  statuscode="$(curl -s -n -k -L -o /dev/null -w "%{http_code}" "$scheme://$1/.well-known/")"
  if [[ ! "${statuscode:0:1}" = "2" && ! "$statuscode" = "404" ]]; then
      scheme="http"
      statuscode="$(curl -s -n -k -L -o /dev/null -w "%{http_code}" "$scheme://$1/.well-known/")"
  fi
  if [[ "$statuscode" == "404" ]]; then
    # create a .well-known folder in portal_skins/custom
    statuscode="$(curl -k -L -n -X POST -d "id=.well-known&submit=Add" -o /dev/null -w "%{http_code}" $scheme://$1/portal_skins/custom/manage_addProduct/OFSP/manage_addFolder)"
    if [[ "${statuscode:0:1}" != 2 ]]; then
      echo "Warning failed to create '.well-know' folder."
    fi
  fi
}

operation="${1}"; shift

case "${operation}" in
    "deploy_challenge")
        while [ "$#" != 0 ]; do
            domain="${1}"; shift
            token_id="${1}"; shift
            token="${1}"; shift
            check_well_known $domain
            statuscode="$(curl -s -k -n -L -o /dev/null -w "%{http_code}" "https://${domain}/.well-known/manage_delObjects?ids:list=acme-challenge")"
            if [[ ! "${statuscode:0:1}" = "2" ]]; then
                statuscode="$(curl -s -n -L -o /dev/null -w "%{http_code}" "http://${domain}/.well-known/manage_delObjects?ids:list=acme-challenge")"
            fi
            statuscode="$(curl -s -k -n -L -o /dev/null -w "%{http_code}" "https://${domain}/.well-known/manage_addProduct/PythonScripts/manage_addPythonScript?id=acme-challenge&file=return%20%27${token}%27")"
            if [[ ! "${statuscode:0:1}" = "2" ]]; then
                statuscode="$(curl -s -n -L -o /dev/null -w "%{http_code}" "http://${domain}/.well-known/manage_addProduct/PythonScripts/manage_addPythonScript?id=acme-challenge&file=return%20%27${token}%27")"
                if [[ ! "${statuscode:0:1}" = "2" ]]; then
                    echo 'Failed'
                    exit 1
                fi
            fi
        done
    ;;
    "clean_challenge")
        while [ "$#" != 0 ]; do
            domain="${1}"; shift
            token_id="${1}"; shift
            token="${1}"; shift
            statuscode="$(curl -s -k -n -L -o /dev/null -w "%{http_code}" "https://${domain}/.well-known/manage_delObjects?ids:list=acme-challenge")"
            if [[ ! "${statuscode:0:1}" = "2" ]]; then
                statuscode="$(curl -s -n -L -o /dev/null -w "%{http_code}" "http://${domain}/.well-known/manage_delObjects?ids:list=acme-challenge")"
                if [[ ! "${statuscode:0:1}" = "2" ]]; then
                    echo 'Failed'
                    exit 1
                fi
            fi
        done
    ;;
esac

exit 0
